@@ -1,13 +1,15 @@
 // -*- C++ -*-
 //
 // This file is part of HepMC
-// Copyright (C) 2014-2019 The HepMC collaboration (see AUTHORS for details)
+// Copyright (C) 2014-2021 The HepMC collaboration (see AUTHORS for details)
 // Part of code was adopted from Pythia8-HepMC interface by Mikhail Kirsanov.
 #ifndef Pythia8_Pythia8ToHepMC3_H
 #define Pythia8_Pythia8ToHepMC3_H
-
+#ifdef  _MSC_VER
+#pragma message("HepMC3 interface is available in the latest versions of Pythia8, see https://pythia.org. This interface will be removed in the future HepMC3 versions.")
+#else
 #warning "HepMC3 interface is available in the latest versions of Pythia8, see https://pythia.org. This interface will be removed in the future HepMC3 versions."
-
+#endif
 #include <vector>
 #include "Pythia8/Pythia.h"
 #include "HepMC3/GenVertex.h"
